@@ -12,26 +12,24 @@ class BlanketCutterStar(ExtrudeStraightShape):
         distance (float): extruded distance (cm) of the cutter which translates
             to being the gap size between blankets when the cutter is used to
             segment blankets.
-        azimuth_placement_angle (iterable of floats or float, optional): the
-            azimuth angle(s) used when positioning the shape. If an iterable of
-            angles is provided, the shape is duplicated at all angles. Defaults
+        height (float, optional): height (cm) of the port. Defaults to 2000.0.
+        width (float, optional): width (cm) of the port. Defaults to 2000.0.
+        azimuth_placement_angle (list or float, optional): Defaults
             to [0., 36., 72., 108., 144., 180., 216., 252., 288., 324.]
-        height (float, optional): height (cm) of the port. Defaults to 2000
-        width (float, optional): width (cm) of the port. Defaults to 2000
-        stp_filename (str, optional): defaults to "BlanketCutterStar.stp".
-        stl_filename (str, optional): defaults to "BlanketCutterStar.stl".
+        stp_filename (str, optional): Defaults to "BlanketCutterStar.stp".
+        stl_filename (str, optional): Defaults to "BlanketCutterStar.stl".
         name (str, optional): defaults to "blanket_cutter_star".
-        material_tag (str, optional): defaults to
+        material_tag (str, optional): Defaults to
             "blanket_cutter_star_mat".
     """
 
     def __init__(
         self,
         distance,
+        height=2000.,
+        width=2000.,
         azimuth_placement_angle=[0., 36., 72., 108., 144., 180., 216., 252.,
                                  288., 324.],
-        height=2000,
-        width=2000,
         stp_filename="BlanketCutterStar.stp",
         stl_filename="BlanketCutterStar.stl",
         name="blanket_cutter_star",
