@@ -1,3 +1,4 @@
+
 from paramak import RotateMixedShape
 
 
@@ -8,41 +9,18 @@ class CenterColumnShieldFlatTopCircular(RotateMixedShape):
 
     Args:
         height (float): height of the center column shield.
-        arc_height (float): height of the outer circlar profile of the center
+        arc_height (float): height of the outer circular profile of the center
             column shield.
         inner_radius (float): the inner radius of the center column shield.
         mid_radius (float): the inner radius of the outer circular profile of
             the center column shield.
         outer_radius (float): the outer radius of the center column shield.
-
-    Keyword Args:
-        name (str): the legend name used when exporting a html graph of the
-            shape.
-        color (sequences of 3 or 4 floats each in the range 0-1): the color to
-            use when exporting as html graphs or png images.
-        material_tag (str): The material name to use when exporting the
-            neutronics description.
-        stp_filename (str): The filename used when saving stp files as part of a
-            reactor.
-        azimuth_placement_angle (float or iterable of floats): The angle or
-            angles to use when rotating the shape on the azimuthal axis.
-        rotation_angle (float): The rotation angle to use when revolving the
-            solid (degrees).
-        workplane (str): The orientation of the CadQuery workplane. Options are
-            XY, YZ or XZ.
-        intersect (CadQuery object): An optional CadQuery object to perform a
-            boolean intersect with this object.
-        cut (CadQuery object): An optional CadQuery object to perform a boolean
-            cut with this object.
-        union (CadQuery object): An optional CadQuery object to perform a
-            boolean union with this object.
-        tet_mesh (str): Insert description.
-        physical_groups (type): Insert description.
-
-    Returns:
-        a paramak shape object: A shape object that has generic functionality
-        with points determined by the find_points() method. A CadQuery solid
-        of the shape can be called via shape.solid.
+        stp_filename (str, optional): Defaults to
+            "CenterColumnShieldFlatTopCircular.stp".
+        stl_filename (str, optional): Defaults to
+            "CenterColumnShieldFlatTopCircular.stl".
+        name (str, optional): Defaults to "center_column".
+        material_tag (str, optional): Defaults to "center_column_shield_mat".
     """
 
     def __init__(
@@ -52,41 +30,19 @@ class CenterColumnShieldFlatTopCircular(RotateMixedShape):
         inner_radius,
         mid_radius,
         outer_radius,
-        rotation_angle=360,
         stp_filename="CenterColumnShieldFlatTopCircular.stp",
         stl_filename="CenterColumnShieldFlatTopCircular.stl",
-        color=(0.5, 0.5, 0.5),
         name="center_column",
         material_tag="center_column_shield_mat",
-        azimuth_placement_angle=0,
         **kwargs
     ):
 
-        default_dict = {
-            "points": None,
-            "workplane": "XZ",
-            "solid": None,
-            "intersect": None,
-            "cut": None,
-            "union": None,
-            "tet_mesh": None,
-            "physical_groups": None,
-        }
-
-        for arg in kwargs:
-            if arg in default_dict:
-                default_dict[arg] = kwargs[arg]
-
         super().__init__(
             name=name,
-            color=color,
             material_tag=material_tag,
             stp_filename=stp_filename,
             stl_filename=stl_filename,
-            azimuth_placement_angle=azimuth_placement_angle,
-            rotation_angle=rotation_angle,
-            hash_value=None,
-            **default_dict
+            **kwargs
         )
 
         self.height = height
