@@ -1,52 +1,33 @@
-from paramak import RotateMixedShape
-from paramak import Plasma
+
+from paramak import Plasma, RotateMixedShape
 
 
 class CenterColumnShieldPlasmaHyperbola(RotateMixedShape):
-    """A center column shield volume with a curvature controlled by the shape of
-    the plasma and offsets specified at the plasma center and edges. Shield
+    """A center column shield volume with a curvature controlled by the shape
+    of the plasma and offsets specified at the plasma center and edges. Shield
     thickness is controlled by the relative values of the shield offsets and
     inner radius.
 
     Args:
-        major_radius (float): the major radius of the plasma.
-        minor_radius (float): the minor radius of the plasma.
-        triangulation (float): the triangularity of the plasma.
-        elongation (float): the elongation of the plasma.
+        height (float): height of the center column shield.
         inner_radius (float): the inner radius of the center column shield.
         mid_offset (float): the offset of the shield from the plasma at the
             plasma center.
         edge_offset (float): the offset of the shield from the plasma at the
             plasma edge.
-
-    Keyword Args:
-        name (str): the legend name used when exporting a html graph of the
-            shape.
-        color (sequences of 3 or 4 floats each in the range 0-1): the color to
-            use when exporting as html graphs or png images.
-        material_tag (str): The material name to use when exporting the
-            neutronics description.
-        stp_filename (str): The filename used when saving stp files as part of a
-            reactor.
-        azimuth_placement_angle (float or iterable of floats): The angle or
-            angles to use when rotating the shape on the azimuthal axis.
-        rotation_angle (float): The rotation angle to use when revolving the
-            solid (degrees).
-        workplane (str): The orientation of the CadQuery workplane. Options are
-            XY, YZ or XZ.
-        intersect (CadQuery object): An optional CadQuery object to perform a
-            boolean intersect with this object.
-        cut (CadQuery object): An optional CadQuery object to perform a boolean
-            cut with this object.
-        union (CadQuery object): An optional CadQuery object to perform a
-            boolean union with this object.
-        tet_mesh (str): Insert description.
-        physical_groups (type): Insert description.
-
-    Returns:
-        a paramak shape object: A shape object that has generic functionality
-        with points determined by the find_points() method. A CadQuery solid of
-        the shape can be called via shape.solid.
+        major_radius (int, optional): the major radius of the plasma. Defaults
+            to 450.0.
+        minor_radius (int, optional): the minor radius of the plasma. Defaults
+            to 150.0.
+        triangularity (float, optional): the triangularity of the plasma.
+            Defaults to 0.55.
+        elongation (float, optional): the elongation of the plasma. Defaults
+            to 2.0.
+        material_tag (str, optional): Defaults to "center_column_shield_mat".
+        stp_filename (str, optional): Defaults to
+            "CenterColumnShieldPlasmaHyperbola.stp".
+        stl_filename (str, optional): Defaults to
+            "CenterColumnShieldPlasmaHyperbola.stl".
     """
 
     def __init__(
@@ -55,45 +36,21 @@ class CenterColumnShieldPlasmaHyperbola(RotateMixedShape):
         inner_radius,
         mid_offset,
         edge_offset,
-        name=None,
-        color=(0.5, 0.5, 0.5),
+        major_radius=450.0,
+        minor_radius=150.0,
+        triangularity=0.55,
+        elongation=2.0,
         material_tag="center_column_shield_mat",
         stp_filename="CenterColumnShieldPlasmaHyperbola.stp",
         stl_filename="CenterColumnShieldPlasmaHyperbola.stl",
-        azimuth_placement_angle=0,
-        rotation_angle=360,
-        major_radius=450,
-        minor_radius=150,
-        triangularity=0.55,
-        elongation=2,
         **kwargs
     ):
 
-        default_dict = {
-            "points": None,
-            "workplane": "XZ",
-            "solid": None,
-            "intersect": None,
-            "cut": None,
-            "union": None,
-            "tet_mesh": None,
-            "physical_groups": None,
-        }
-
-        for arg in kwargs:
-            if arg in default_dict:
-                default_dict[arg] = kwargs[arg]
-
         super().__init__(
-            name=name,
-            color=color,
             material_tag=material_tag,
             stp_filename=stp_filename,
             stl_filename=stl_filename,
-            azimuth_placement_angle=azimuth_placement_angle,
-            rotation_angle=rotation_angle,
-            hash_value=None,
-            **default_dict
+            **kwargs
         )
 
         self.major_radius = major_radius
